@@ -1,6 +1,7 @@
 from functools import lru_cache
 from typing import Optional
 
+from django.core.exceptions import FieldDoesNotExist
 from django.db import models
 from django.db.models import QuerySet
 from rest_framework.compat import coreapi, coreschema
@@ -85,7 +86,7 @@ class FlexFieldsFilterBackend(BaseFilterBackend):
         try:
             # noinspection PyProtectedMember
             return model._meta.get_field(field_name)
-        except models.FieldDoesNotExist:
+        except FieldDoesNotExist:
             return None
 
     def get_schema_fields(self, view):
@@ -131,3 +132,46 @@ class FlexFieldsFilterBackend(BaseFilterBackend):
                 example="nested1,nested2",
             ),
         ]
+
+    def get_schema_operation_parameters(self, view):
+
+        if not issubclass(view.get_serializer_class(), FlexFieldsSerializerMixin):
+            return []
+
+        parameters = [
+            {
+                "name": "fields",
+                "required": False,
+                "in": "query",
+                "description": "Specify required field by comma",
+                "schema": {
+                    "title": "Selected fields",
+                    "type": "string",
+                },
+                "example": "field1,field2,nested.field",
+            },
+            {
+                "name": "omit",
+                "required": False,
+                "in": "query",
+                "description": "Specify required field by comma",
+                "schema": {
+                    "title": "Omitted fields",
+                    "type": "string",
+                },
+                "example": "field1,field2,nested.field",
+            },
+            {
+                "name": "expand",
+                "required": False,
+                "in": "query",
+                "description": "Specify required field by comma",
+                "schema": {
+                    "title": "Expanded fields",
+                    "type": "string",
+                },
+                "example": "nested1,nested2",
+            },
+        ]
+
+        return parameters
